function [dataClean, dataReject, nVarClean, nVarReject, EEG]=cleanica(EEG);
%Clean data from artifact
%
% Usage: [dataClean, dataReject, nVarClean, nVarReject, EEGNEW]=cleanica(EEG)
%
%	You can get EEG so:
%		EEG=data2eeglabdataset(eeg); %eeg= data in columns
%		EEG=oTest2eeglabdataset(oTest);
%		EEG=vi_eeg02eeglab(oEEG);
%
% ver 1.1 (c) Dmitry Sherbina 2003-2013

%1.1	2013-02-22	compatible w eeglab 12.x
%1.03	2007-03-24	eeglab 5.03 - direct runica
%1.02	2006-06-14	reject bug => eeg_checkset
%1.01 - close(hICAplot);
if nargin<1
	help cleanica
	return
end
dataClean=[];
dataReject=[];
nVarClean=[];
nVarReject=[];
if isempty(EEG.icaweights)
        [EEG.icaweights,EEG.icasphere] = runica(EEG.data, 'lrate', 0.001, 'extended', 0,'verbose','on');
%	EEG=pop_runica(EEG, 'runica','extended', 0,'verbose','off');
	%mark 1st rejected
else
	disp('EEG.icaweights already exist. To recalculate: empty ICA fields')
end
nICA=size(EEG.icaweights,1);
EEG=eeg_checkset(EEG);
if isempty(EEG.reject.gcompreject)
	EEG.reject.gcompreject=zeros(1,nICA);
	%by default mark for rejection 1st
%!!!!!!!!!!!!!!!!!! by correlation with topos
	EEG.reject.gcompreject(1)=1;
end
%plot ICA
pop_eegplot(EEG, 0, 1, 0);
hICAplot=gcf;
g=get(hICAplot,'UserData');
g.winlength=20;
arColorDefault=g.color{1};
sColorDefault=['[',num2str(arColorDefault),']'];
sColorSelected='[1 0 0]';
cColors(1:g.chans,1)={arColorDefault};
cColors(nICA+1-find(EEG.reject.gcompreject))={eval(sColorSelected)};
g.color=cColors;
set(hICAplot,'UserData',g);
%correct YScale, for 'extended' use 5 for same amplitude
set(findobj(hICAplot,'Tag','ESpacing'),'String',15);
eval(get(findobj(hICAplot,'Tag','ESpacing'),'Callback'));
%show topo
pop_selectcomps(EEG, [1:nICA]);
sTag='comp';
COLREJ='[1 0.6 0.6]';
COLACC='[0.75 1 0.75]';
sCommand=['switchBackgroundColor(gcbo,',COLACC,',',COLREJ,');i=',num2str(nICA+1),'-str2num(get(gcbo,''String''));g=get(',num2str(hICAplot),',''UserData'');g.color{i}=fastif(g.color{i}==',sColorDefault,',',sColorSelected,',',sColorDefault,');set(',num2str(hICAplot),',''UserData'',g);'];
for i=1:nICA
	set(findobj(gcf,'Tag',[sTag,int2str(i)]),'Callback',sCommand);
end
sCommand=['uiresume(gcbf);'];
set(findobj(gcf,'string','OK'),'Callback',sCommand);
sTopoplotTag=get(gcf,'Tag');
%sound alert
try
wavplay(wavread('help2choice.wav'),22050)
catch
end
uiwait(gcf)
%check if close
if ~strcmp(sTopoplotTag,get(gcf,'Tag'))
	return
end
iiCompReject=onOK(COLREJ,sTag);
if isempty(iiCompReject)
	dataReject=[];
	nVarReject=0;
	dataClean=EEG.data';
	nVarClean=1;
	EEG.reject.gcompreject(:)=0;
else
	if ~isempty(EEG.icaact)
		icaact=EEG.icaact;
	else
		icaact=(EEG.icaweights * EEG.icasphere) * EEG.data;
		%icaact=eeg_getdatact(EEG);
	end
[dataReject, nVarReject]=compvar(EEG.data, icaact, EEG.icawinv, iiCompReject);dataReject=dataReject';
iiCompGood=setdiff([1:size(EEG.icaweights,1)], iiCompReject);
[dataClean, nVarClean]=compvar(EEG.data, icaact, EEG.icawinv, iiCompGood);dataClean=dataClean';
EEG.reject.gcompreject(iiCompReject)=1;
end
%close ICAplot
close(hICAplot);
close;

function iiCompReject=onOK(COLREJ,sTag)
ss=char(get(findobj(gcf,'BackgroundColor',str2num(COLREJ)),'Tag'));
if isempty(ss)
	iiCompReject=[]
	return
end
ss=ss(:,(length(sTag)+1):end);
iiCompReject=sort(str2num(ss))';

if strcmp(questdlg(['Delete comps: ',int2str(iiCompReject)],'cleanica'),'Yes');
else
%!!!!!!!!!to diff No and Cancel
	uiwait(gcf);
	iiCompReject=onOK(COLREJ,sTag);
end
